<?PHP
require_once __DIR__ . '/google-api-php-client-2.2.1/vendor/autoload.php'; // ライブラリの設定
define("_KEY_FILE_LOCATION",__DIR__ . '/my.json'); // 認証キーファイルの設定
define("_VIEW_ID","00000000");	// ビューIDの設定

// 認証
$analytics = initializeAnalytics();

// レポート取得
$response = getReport($analytics);

echo "<pre>";
print_r( procResults($response) );
echo "</pre>";

exit();

?>
<?PHP
//******************************************************************************
//
// 認証
//
//******************************************************************************
function initializeAnalytics()
{
	$client = new Google_Client();
	$client->setAuthConfig(_KEY_FILE_LOCATION);
	$client->setScopes(['https://www.googleapis.com/auth/analytics.readonly']);
	$analytics = new Google_Service_AnalyticsReporting($client);
	return $analytics;
}

//******************************************************************************
//
// レポート取得
//
//******************************************************************************
function getReport($analytics) {

	// 対象期間
	$dateRange = new Google_Service_AnalyticsReporting_DateRange();
	$dateRange->setStartDate("2daysAgo"); // 開始日
	$dateRange->setEndDate("today"); // 終了日

	// セッション
	$sessions = new Google_Service_AnalyticsReporting_Metric();
	$sessions->setExpression("ga:sessions");
	$sessions->setAlias("sessions");

	// ページビュー
	$pageviews = new Google_Service_AnalyticsReporting_Metric();
	$pageviews->setExpression("ga:pageviews"); 
	$pageviews->setAlias("pageviews");

	// 日別
	$date = new Google_Service_AnalyticsReporting_Dimension();
	$date->setName("ga:date");


	// リクエストの作成
	$request = new Google_Service_AnalyticsReporting_ReportRequest();
	$request->setViewId(_VIEW_ID); // ビューID
	$request->setDateRanges($dateRange); // 対象期間
	$request->setMetrics(array($sessions,$pageviews)); // セッション及びページビュー
	$request->setDimensions(array($date)); // 日別

	// レポートの取得
	$body = new Google_Service_AnalyticsReporting_GetReportsRequest();
	$body->setReportRequests( array( $request) );
	return $analytics->reports->batchGet( $body );
}

//******************************************************************************
//
// データ加工
//
//******************************************************************************
function procResults($reports) {

	$ret = array();

	for ( $reportIndex = 0; $reportIndex < count( $reports ); $reportIndex++ ) {
		$report = $reports[ $reportIndex ];
		$header = $report->getColumnHeader();
		$dimensionHeaders = $header->getDimensions();
		$metricHeaders = $header->getMetricHeader()->getMetricHeaderEntries();
		$rows = $report->getData()->getRows();

		for ( $rowIndex = 0; $rowIndex < count($rows); $rowIndex++) {
			$work = array();

			$row = $rows[ $rowIndex ];
			$dimensions = $row->getDimensions();
			$metrics = $row->getMetrics();
			for ($i = 0; $i < count($dimensionHeaders) && $i < count($dimensions); $i++) {
				$work[$dimensionHeaders[$i]] = $dimensions[$i];
			}

			$metrics = $metrics[0]->getValues();

			for ($j = 0; $j < count( $metricHeaders ) && $j < count( $metrics ); $j++) {
				$entry = $metricHeaders[$j];
				$values = $metrics;
				$work[$entry->getName()] = $values[$j];
			}
			$ret[] = $work;
		}
	}
	return $ret;
}
?>
